==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/sn_invite.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['section_invite'] = 						"build your social network";
$lang['section_sent'] = 						"sent";
$lang['hdr_invite'] = 							"invite your friends!";
$lang['hdr_email'] = 							"customise the email";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"INVITE NOW!";


//FORM
$lang['form_emails'] = 							"email addresses";
$lang['form_subject'] = 						"subject";
$lang['form_message'] = 						"message";


//BODY TEXT
$lang['txt_invite_help'] = 						"Type in the email addresses of your friends to invite them in.";
$lang['txt_email_intro'] =						"This is the subject and message that will be sent to your friends. You can change the content if you would like to send a personalised email.";
$lang['txt_emails_sent'] =						"emails sent";
$lang['txt_invite'] =							"Join me in Aroundme!";
$lang['txt_invite_message_txt'] =				"Aroundme is a social networking and group collaboration platform. Press the link below to join me inside.";
$lang['txt_invite_to_help'] =					"Hint: You can either put each email address on a new line or use a comma (,) between them like 'foo@barnraiser.org, bar@barnraiser.org'. We do not recommend sending more than 25 emails at a time.";


//$lang['txt_invite_message_help'] =				"You can change the text if you want.";
//section titles
//


?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/sn_invite.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['section_invite'] = 						"build your social network";
$lang['section_sent'] = 						"sent";
$lang['hdr_invite'] = 							"invite your friends!";
$lang['hdr_email'] = 							"customise the email";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"INVITE NOW!";


// ERR
$lang['err_invite_denied'] = 					"Sorry, you do not have permissions to invite people into this network.";


//FORM
$lang['form_emails'] = 							"email addresses";
$lang['form_subject'] = 						"subject";
$lang['form_message'] = 						"message";


//BODY TEXT
$lang['txt_invite_help'] = 						"Type in the email addresses of your friends to invite them in.";
$lang['txt_email_intro'] =						"This is the subject and message that will be sent to your friends. You can change the content if you would like to send a personalised email.";
$lang['txt_emails_sent'] =						"emails sent";
$lang['txt_invite'] =							"Join me in Aroundme!";
$lang['txt_invite_message_txt'] =				"Aroundme is a social networking and group collaboration platform. Press the link below to join me inside.";
$lang['txt_invite_to_help'] =					"Hint: You can either put each email address on a new line or use a comma (,) between them like 'foo@barnraiser.org, bar@barnraiser.org'. We do not recommend sending more than 25 emails at a time.";

?>
